changeset 6:cfc7683e73f9

Fix breakage from r33 by completing update of move to IBBoard.WarFoundry.GTK sub-packages no-open-ticket
author IBBoard <dev@ibboard.co.uk>
date Mon, 26 Jan 2009 20:16:07 +0000
parents 65279b85446f
children 58961ff391d4
files FrmMainWindow.cs WarFoundryGUI.mdp gtk-gui/IBBoard.WarFoundry.GTK.FrmChangeGameSystem.cs gtk-gui/IBBoard.WarFoundry.GTK.FrmMainWindow.cs gtk-gui/IBBoard.WarFoundry.GTK.FrmNewArmy.cs gtk-gui/IBBoard.WarFoundry.GTK.FrmNewUnit.cs gtk-gui/IBBoard.WarFoundry.GTK.Widgets.UnitDisplayWidget.cs gtk-gui/generated.cs
diffstat 8 files changed, 81 insertions(+), 81 deletions(-) [+]
line wrap: on
line diff
--- a/FrmMainWindow.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/FrmMainWindow.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -21,7 +21,7 @@
 using IBBoard.WarFoundry.API.Commands;
 using IBBoard.WarFoundry.API.Savers;
 using IBBoard.WarFoundry.API.Requirements;
-using IBBoard.WarFoundry.Widgets;
+using IBBoard.WarFoundry.GTK.Widgets;
 using IBBoard.WarFoundry.Plugin.Rollcall;
 using IBBoard.Xml;
 using log4net;
--- a/WarFoundryGUI.mdp	Sun Jan 25 14:52:18 2009 +0000
+++ b/WarFoundryGUI.mdp	Mon Jan 26 20:16:07 2009 +0000
@@ -1,17 +1,17 @@
 <Project name="WarFoundry GTK# GUI" fileversion="2.0" language="C#" DefaultNamespace="IBBoard.WarFoundry.GTK" clr-version="Net_2_0" Description="A GTK# GUI for the WarFoundry army builder application." ctype="DotNetProject">
   <Configurations active="Debug">
     <Configuration name="Debug" ctype="DotNetProjectConfiguration">
-      <Output directory="bin/Debug" assemblyKeyFile="." assembly="WarFoundryGTK" />
+      <Output directory="bin/Debug" assemblyKeyFile="/home/ibboard/eclipse/IBBoard.WarFoundry.GUI.GTK/." assembly="WarFoundryGTK" />
       <Build debugmode="True" target="Exe" />
       <Execution runwithwarnings="True" consolepause="True" runtime="MsNet" clr-version="Net_2_0" />
       <EnvironmentVariables />
-      <CodeGeneration compiler="Mcs" warninglevel="4" optimize="True" unsafecodeallowed="False" generateoverflowchecks="True" mainclass="IBBoard.WarFoundry.FrmMainWindow" generatexmldocumentation="False" win32Icon="App.ico" ctype="CSharpCompilerParameters" />
+      <CodeGeneration compiler="Mcs" warninglevel="4" optimize="True" unsafecodeallowed="False" generateoverflowchecks="True" mainclass="IBBoard.WarFoundry.GTK.FrmMainWindow" generatexmldocumentation="False" win32Icon="/home/ibboard/eclipse/IBBoard.WarFoundry.GUI.GTK/App.ico" ctype="CSharpCompilerParameters" />
     </Configuration>
     <Configuration name="Release" ctype="DotNetProjectConfiguration">
       <Output directory="bin/Release" assembly="WarFoundryGTK" />
       <Build debugmode="False" target="Exe" />
       <Execution runwithwarnings="True" consolepause="True" runtime="MsNet" clr-version="Net_2_0" />
-      <CodeGeneration compiler="Mcs" warninglevel="4" optimize="True" unsafecodeallowed="False" generateoverflowchecks="True" generatexmldocumentation="False" ctype="CSharpCompilerParameters" />
+      <CodeGeneration compiler="Mcs" warninglevel="4" optimize="True" unsafecodeallowed="False" generateoverflowchecks="True" mainclass="IBBoard.WarFoundry.GTK.FrmMainWindow" generatexmldocumentation="False" win32Icon="/home/ibboard/eclipse/IBBoard.WarFoundry.GUI.GTK/App.ico" ctype="CSharpCompilerParameters" />
     </Configuration>
   </Configurations>
   <Contents>
@@ -51,5 +51,5 @@
     <ProjectReference type="Gac" localcopy="True" refto="gdk-sharp, Version=2.12.0.0, Culture=neutral, PublicKeyToken=35e10195dab3c99f" />
   </References>
   <Deployment.LinuxDeployData scriptName="warfoundry_gui" />
-  <GtkDesignInfo />
+  <GtkDesignInfo generateGettext="False" />
 </Project>
\ No newline at end of file
--- a/gtk-gui/IBBoard.WarFoundry.GTK.FrmMainWindow.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/gtk-gui/IBBoard.WarFoundry.GTK.FrmMainWindow.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -1,14 +1,14 @@
 // ------------------------------------------------------------------------------
 //  <autogenerated>
 //      This code was generated by a tool.
-//      Mono Runtime Version: 2.0.50727.42
+//      Mono Runtime Version: 2.0.50727.1433
 // 
 //      Changes to this file may cause incorrect behavior and will be lost if 
 //      the code is regenerated.
 //  </autogenerated>
 // ------------------------------------------------------------------------------
 
-namespace IBBoard.WarFoundry {
+namespace IBBoard.WarFoundry.GTK {
     
     
     public partial class FrmMainWindow {
@@ -75,61 +75,61 @@
         
         protected virtual void Build() {
             Stetic.Gui.Initialize(this);
-            // Widget IBBoard.WarFoundry.FrmMainWindow
+            // Widget IBBoard.WarFoundry.GTK.FrmMainWindow
             this.UIManager = new Gtk.UIManager();
             Gtk.ActionGroup w1 = new Gtk.ActionGroup("Default");
-            this.menuFile = new Gtk.Action("menuFile", Mono.Unix.Catalog.GetString("File"), null, null);
-            this.menuFile.ShortLabel = Mono.Unix.Catalog.GetString("File");
+            this.menuFile = new Gtk.Action("menuFile", "File", null, null);
+            this.menuFile.ShortLabel = "File";
             w1.Add(this.menuFile, null);
-            this.miCreateArmy = new Gtk.Action("miCreateArmy", Mono.Unix.Catalog.GetString("Create army"), null, null);
+            this.miCreateArmy = new Gtk.Action("miCreateArmy", "Create army", null, null);
             this.miCreateArmy.Sensitive = false;
-            this.miCreateArmy.ShortLabel = Mono.Unix.Catalog.GetString("Create army");
+            this.miCreateArmy.ShortLabel = "Create army";
             w1.Add(this.miCreateArmy, null);
-            this.miOpenArmy = new Gtk.Action("miOpenArmy", Mono.Unix.Catalog.GetString("Open army"), null, null);
+            this.miOpenArmy = new Gtk.Action("miOpenArmy", "Open army", null, null);
             this.miOpenArmy.Sensitive = false;
-            this.miOpenArmy.ShortLabel = Mono.Unix.Catalog.GetString("Open army");
+            this.miOpenArmy.ShortLabel = "Open army";
             w1.Add(this.miOpenArmy, null);
-            this.miSaveArmy = new Gtk.Action("miSaveArmy", Mono.Unix.Catalog.GetString("Save army"), null, null);
+            this.miSaveArmy = new Gtk.Action("miSaveArmy", "Save army", null, null);
             this.miSaveArmy.Sensitive = false;
-            this.miSaveArmy.ShortLabel = Mono.Unix.Catalog.GetString("Save army");
+            this.miSaveArmy.ShortLabel = "Save army";
             w1.Add(this.miSaveArmy, null);
-            this.miSaveArmyAs = new Gtk.Action("miSaveArmyAs", Mono.Unix.Catalog.GetString("Save army as"), null, null);
+            this.miSaveArmyAs = new Gtk.Action("miSaveArmyAs", "Save army as", null, null);
             this.miSaveArmyAs.Sensitive = false;
-            this.miSaveArmyAs.ShortLabel = Mono.Unix.Catalog.GetString("Save army as");
+            this.miSaveArmyAs.ShortLabel = "Save army as";
             w1.Add(this.miSaveArmyAs, null);
-            this.miCloseArmy = new Gtk.Action("miCloseArmy", Mono.Unix.Catalog.GetString("Close army"), null, null);
+            this.miCloseArmy = new Gtk.Action("miCloseArmy", "Close army", null, null);
             this.miCloseArmy.Sensitive = false;
-            this.miCloseArmy.ShortLabel = Mono.Unix.Catalog.GetString("Close army");
+            this.miCloseArmy.ShortLabel = "Close army";
             w1.Add(this.miCloseArmy, null);
-            this.miChangeGameSystem = new Gtk.Action("miChangeGameSystem", Mono.Unix.Catalog.GetString("Change game system"), null, null);
-            this.miChangeGameSystem.ShortLabel = Mono.Unix.Catalog.GetString("Change game system");
+            this.miChangeGameSystem = new Gtk.Action("miChangeGameSystem", "Change game system", null, null);
+            this.miChangeGameSystem.ShortLabel = "Change game system";
             w1.Add(this.miChangeGameSystem, null);
-            this.miReloadFiles = new Gtk.Action("miReloadFiles", Mono.Unix.Catalog.GetString("Reload files"), null, null);
+            this.miReloadFiles = new Gtk.Action("miReloadFiles", "Reload files", null, null);
             this.miReloadFiles.Sensitive = false;
-            this.miReloadFiles.ShortLabel = Mono.Unix.Catalog.GetString("Reload files");
+            this.miReloadFiles.ShortLabel = "Reload files";
             w1.Add(this.miReloadFiles, null);
-            this.miExit = new Gtk.Action("miExit", Mono.Unix.Catalog.GetString("Exit"), null, null);
-            this.miExit.ShortLabel = Mono.Unix.Catalog.GetString("Exit");
+            this.miExit = new Gtk.Action("miExit", "Exit", null, null);
+            this.miExit.ShortLabel = "Exit";
             w1.Add(this.miExit, null);
-            this.menuEdit = new Gtk.Action("menuEdit", Mono.Unix.Catalog.GetString("Edit"), null, null);
-            this.menuEdit.ShortLabel = Mono.Unix.Catalog.GetString("Edit");
+            this.menuEdit = new Gtk.Action("menuEdit", "Edit", null, null);
+            this.menuEdit.ShortLabel = "Edit";
             w1.Add(this.menuEdit, null);
-            this.miUndo = new Gtk.Action("miUndo", Mono.Unix.Catalog.GetString("Undo"), null, null);
+            this.miUndo = new Gtk.Action("miUndo", "Undo", null, null);
             this.miUndo.Sensitive = false;
-            this.miUndo.ShortLabel = Mono.Unix.Catalog.GetString("Undo");
+            this.miUndo.ShortLabel = "Undo";
             w1.Add(this.miUndo, null);
-            this.miRedo = new Gtk.Action("miRedo", Mono.Unix.Catalog.GetString("Redo"), null, null);
+            this.miRedo = new Gtk.Action("miRedo", "Redo", null, null);
             this.miRedo.Sensitive = false;
-            this.miRedo.ShortLabel = Mono.Unix.Catalog.GetString("Redo");
+            this.miRedo.ShortLabel = "Redo";
             w1.Add(this.miRedo, null);
-            this.menuHelp = new Gtk.Action("menuHelp", Mono.Unix.Catalog.GetString("Help"), null, null);
-            this.menuHelp.ShortLabel = Mono.Unix.Catalog.GetString("Help");
+            this.menuHelp = new Gtk.Action("menuHelp", "Help", null, null);
+            this.menuHelp.ShortLabel = "Help";
             w1.Add(this.menuHelp, null);
-            this.miAbout = new Gtk.Action("miAbout", Mono.Unix.Catalog.GetString("About"), null, null);
-            this.miAbout.ShortLabel = Mono.Unix.Catalog.GetString("About");
+            this.miAbout = new Gtk.Action("miAbout", "About", null, null);
+            this.miAbout.ShortLabel = "About";
             w1.Add(this.miAbout, null);
-            this.miDebugInformation = new Gtk.Action("miDebugInformation", Mono.Unix.Catalog.GetString("Debug Information"), null, null);
-            this.miDebugInformation.ShortLabel = Mono.Unix.Catalog.GetString("Debug Information");
+            this.miDebugInformation = new Gtk.Action("miDebugInformation", "Debug Information", null, null);
+            this.miDebugInformation.ShortLabel = "Debug Information";
             w1.Add(this.miDebugInformation, null);
             this.newArmyButton = new Gtk.Action("newArmyButton", null, null, "gtk-new");
             this.newArmyButton.Sensitive = false;
@@ -152,10 +152,10 @@
             w1.Add(this.add, null);
             this.UIManager.InsertActionGroup(w1, 0);
             this.AddAccelGroup(this.UIManager.AccelGroup);
-            this.Name = "IBBoard.WarFoundry.FrmMainWindow";
-            this.Title = Mono.Unix.Catalog.GetString("MainWindow");
+            this.Name = "IBBoard.WarFoundry.GTK.FrmMainWindow";
+            this.Title = "MainWindow";
             this.Icon = Gdk.Pixbuf.LoadFromResource("App.ico");
-            // Container child IBBoard.WarFoundry.FrmMainWindow.Gtk.Container+ContainerChild
+            // Container child IBBoard.WarFoundry.GTK.FrmMainWindow.Gtk.Container+ContainerChild
             this.vbox1 = new Gtk.VBox();
             this.vbox1.Name = "vbox1";
             // Container child vbox1.Gtk.Box+BoxChild
--- a/gtk-gui/IBBoard.WarFoundry.GTK.Widgets.UnitDisplayWidget.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/gtk-gui/IBBoard.WarFoundry.GTK.Widgets.UnitDisplayWidget.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -1,14 +1,14 @@
 // ------------------------------------------------------------------------------
 //  <autogenerated>
 //      This code was generated by a tool.
-//      Mono Runtime Version: 2.0.50727.42
+//      Mono Runtime Version: 2.0.50727.1433
 // 
 //      Changes to this file may cause incorrect behavior and will be lost if 
 //      the code is regenerated.
 //  </autogenerated>
 // ------------------------------------------------------------------------------
 
-namespace IBBoard.WarFoundry.Widgets {
+namespace IBBoard.WarFoundry.GTK.Widgets {
     
     
     public partial class UnitDisplayWidget {
@@ -59,10 +59,10 @@
         
         protected virtual void Build() {
             Stetic.Gui.Initialize(this);
-            // Widget IBBoard.WarFoundry.Widgets.UnitDisplayWidget
+            // Widget IBBoard.WarFoundry.GTK.Widgets.UnitDisplayWidget
             Stetic.BinContainer.Attach(this);
-            this.Name = "IBBoard.WarFoundry.Widgets.UnitDisplayWidget";
-            // Container child IBBoard.WarFoundry.Widgets.UnitDisplayWidget.Gtk.Container+ContainerChild
+            this.Name = "IBBoard.WarFoundry.GTK.Widgets.UnitDisplayWidget";
+            // Container child IBBoard.WarFoundry.GTK.Widgets.UnitDisplayWidget.Gtk.Container+ContainerChild
             this.vbox1 = new Gtk.VBox();
             this.vbox1.Name = "vbox1";
             this.vbox1.Spacing = 6;
@@ -155,7 +155,7 @@
             // Container child table1.Gtk.Table+TableChild
             this.optionalEquipmentLabel = new Gtk.Label();
             this.optionalEquipmentLabel.Name = "optionalEquipmentLabel";
-            this.optionalEquipmentLabel.LabelProp = Mono.Unix.Catalog.GetString("Optional Equipment:");
+            this.optionalEquipmentLabel.LabelProp = "Optional Equipment:";
             this.table1.Add(this.optionalEquipmentLabel);
             Gtk.Table.TableChild w11 = ((Gtk.Table.TableChild)(this.table1[this.optionalEquipmentLabel]));
             w11.TopAttach = ((uint)(1));
@@ -165,7 +165,7 @@
             // Container child table1.Gtk.Table+TableChild
             this.requiredEquipmentLabel = new Gtk.Label();
             this.requiredEquipmentLabel.Name = "requiredEquipmentLabel";
-            this.requiredEquipmentLabel.LabelProp = Mono.Unix.Catalog.GetString("Required Equipment:");
+            this.requiredEquipmentLabel.LabelProp = "Required Equipment:";
             this.table1.Add(this.requiredEquipmentLabel);
             Gtk.Table.TableChild w12 = ((Gtk.Table.TableChild)(this.table1[this.requiredEquipmentLabel]));
             w12.XOptions = ((Gtk.AttachOptions)(4));
@@ -179,7 +179,7 @@
             this.bttnReplaceRequired.CanFocus = true;
             this.bttnReplaceRequired.Name = "bttnReplaceRequired";
             this.bttnReplaceRequired.UseUnderline = true;
-            this.bttnReplaceRequired.Label = Mono.Unix.Catalog.GetString("Replace");
+            this.bttnReplaceRequired.Label = "Replace";
             this.vbox2.Add(this.bttnReplaceRequired);
             Gtk.Box.BoxChild w13 = ((Gtk.Box.BoxChild)(this.vbox2[this.bttnReplaceRequired]));
             w13.Position = 0;
@@ -190,7 +190,7 @@
             this.bttnEditRequired.CanFocus = true;
             this.bttnEditRequired.Name = "bttnEditRequired";
             this.bttnEditRequired.UseUnderline = true;
-            this.bttnEditRequired.Label = Mono.Unix.Catalog.GetString("Edit");
+            this.bttnEditRequired.Label = "Edit";
             this.vbox2.Add(this.bttnEditRequired);
             Gtk.Box.BoxChild w14 = ((Gtk.Box.BoxChild)(this.vbox2[this.bttnEditRequired]));
             w14.Position = 1;
@@ -211,7 +211,7 @@
             this.bttnAddOptional.CanFocus = true;
             this.bttnAddOptional.Name = "bttnAddOptional";
             this.bttnAddOptional.UseUnderline = true;
-            this.bttnAddOptional.Label = Mono.Unix.Catalog.GetString("Add");
+            this.bttnAddOptional.Label = "Add";
             this.vbox3.Add(this.bttnAddOptional);
             Gtk.Box.BoxChild w16 = ((Gtk.Box.BoxChild)(this.vbox3[this.bttnAddOptional]));
             w16.Position = 0;
@@ -222,7 +222,7 @@
             this.bttnEditOptional.CanFocus = true;
             this.bttnEditOptional.Name = "bttnEditOptional";
             this.bttnEditOptional.UseUnderline = true;
-            this.bttnEditOptional.Label = Mono.Unix.Catalog.GetString("Edit");
+            this.bttnEditOptional.Label = "Edit";
             this.vbox3.Add(this.bttnEditOptional);
             Gtk.Box.BoxChild w17 = ((Gtk.Box.BoxChild)(this.vbox3[this.bttnEditOptional]));
             w17.Position = 1;
@@ -233,7 +233,7 @@
             this.bttnRemove.CanFocus = true;
             this.bttnRemove.Name = "bttnRemove";
             this.bttnRemove.UseUnderline = true;
-            this.bttnRemove.Label = Mono.Unix.Catalog.GetString("Remove");
+            this.bttnRemove.Label = "Remove";
             this.vbox3.Add(this.bttnRemove);
             Gtk.Box.BoxChild w18 = ((Gtk.Box.BoxChild)(this.vbox3[this.bttnRemove]));
             w18.Position = 2;
--- a/gtk-gui/generated.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/gtk-gui/generated.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -1,7 +1,7 @@
 // ------------------------------------------------------------------------------
 //  <autogenerated>
 //      This code was generated by a tool.
-//      Mono Runtime Version: 2.0.50727.42
+//      Mono Runtime Version: 2.0.50727.1433
 // 
 //      Changes to this file may cause incorrect behavior and will be lost if 
 //      the code is regenerated.
--- a/gtk-gui/IBBoard.WarFoundry.GTK.FrmChangeGameSystem.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/gtk-gui/IBBoard.WarFoundry.GTK.FrmChangeGameSystem.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -1,14 +1,14 @@
 // ------------------------------------------------------------------------------
 //  <autogenerated>
 //      This code was generated by a tool.
-//      Mono Runtime Version: 2.0.50727.42
+//      Mono Runtime Version: 2.0.50727.1433
 // 
 //      Changes to this file may cause incorrect behavior and will be lost if 
 //      the code is regenerated.
 //  </autogenerated>
 // ------------------------------------------------------------------------------
 
-namespace IBBoard.WarFoundry {
+namespace IBBoard.WarFoundry.GTK {
     
     
     public partial class FrmChangeGameSystem {
@@ -27,9 +27,9 @@
         
         protected virtual void Build() {
             Stetic.Gui.Initialize(this);
-            // Widget IBBoard.WarFoundry.FrmChangeGameSystem
-            this.Name = "IBBoard.WarFoundry.FrmChangeGameSystem";
-            this.Title = Mono.Unix.Catalog.GetString("Change Game System");
+            // Widget IBBoard.WarFoundry.GTK.FrmChangeGameSystem
+            this.Name = "IBBoard.WarFoundry.GTK.FrmChangeGameSystem";
+            this.Title = "Change Game System";
             this.Icon = Gdk.Pixbuf.LoadFromResource("App.ico");
             this.TypeHint = ((Gdk.WindowTypeHint)(1));
             this.WindowPosition = ((Gtk.WindowPosition)(4));
@@ -41,7 +41,7 @@
             this.SkipPagerHint = true;
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
             // Internal child IBBoard.WarFoundry.FrmChangeGameSystem.VBox
             Gtk.VBox w1 = this.VBox;
             w1.Name = "dialog1_VBox";
             w1.Spacing = 6;
@@ -53,7 +53,7 @@
             // Container child hbox1.Gtk.Box+BoxChild
             this.lblGameSystem = new Gtk.Label();
             this.lblGameSystem.Name = "lblGameSystem";
-            this.lblGameSystem.LabelProp = Mono.Unix.Catalog.GetString("Game System");
+            this.lblGameSystem.LabelProp = "Game System";
             this.hbox1.Add(this.lblGameSystem);
             Gtk.Box.BoxChild w2 = ((Gtk.Box.BoxChild)(this.hbox1[this.lblGameSystem]));
             w2.Position = 0;
@@ -77,7 +77,7 @@
             w1.Add(this.hbox1);
             Gtk.Box.BoxChild w5 = ((Gtk.Box.BoxChild)(w1[this.hbox1]));
             w5.Position = 0;
             // Internal child IBBoard.WarFoundry.FrmChangeGameSystem.ActionArea
             Gtk.HButtonBox w6 = this.ActionArea;
             w6.Name = "dialog1_ActionArea";
             w6.Spacing = 6;
@@ -41,7 +41,7 @@
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
-            // Internal child IBBoard.WarFoundry.FrmChangeGameSystem.VBox
+            // Internal child IBBoard.WarFoundry.GTK.FrmChangeGameSystem.VBox
             Gtk.VBox w1 = this.VBox;
             w1.Name = "dialog1_VBox";
@@ -77,7 +77,7 @@
             Gtk.Box.BoxChild w5 = ((Gtk.Box.BoxChild)(w1[this.hbox1]));
             w5.Position = 0;
-            // Internal child IBBoard.WarFoundry.FrmChangeGameSystem.ActionArea
+            // Internal child IBBoard.WarFoundry.GTK.FrmChangeGameSystem.ActionArea
             Gtk.HButtonBox w6 = this.ActionArea;
             w6.Name = "dialog1_ActionArea";
--- a/gtk-gui/IBBoard.WarFoundry.GTK.FrmNewArmy.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/gtk-gui/IBBoard.WarFoundry.GTK.FrmNewArmy.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -1,14 +1,14 @@
 // ------------------------------------------------------------------------------
 //  <autogenerated>
 //      This code was generated by a tool.
-//      Mono Runtime Version: 2.0.50727.42
+//      Mono Runtime Version: 2.0.50727.1433
 // 
 //      Changes to this file may cause incorrect behavior and will be lost if 
 //      the code is regenerated.
 //  </autogenerated>
 // ------------------------------------------------------------------------------
 
-namespace IBBoard.WarFoundry {
+namespace IBBoard.WarFoundry.GTK {
     
     
     public partial class FrmNewArmy {
@@ -37,16 +37,16 @@
         
         protected virtual void Build() {
             Stetic.Gui.Initialize(this);
-            // Widget IBBoard.WarFoundry.FrmNewArmy
+            // Widget IBBoard.WarFoundry.GTK.FrmNewArmy
             this.Events = ((Gdk.EventMask)(256));
-            this.Name = "IBBoard.WarFoundry.FrmNewArmy";
-            this.Title = Mono.Unix.Catalog.GetString("Create new army");
+            this.Name = "IBBoard.WarFoundry.GTK.FrmNewArmy";
+            this.Title = "Create new army";
             this.Icon = Stetic.IconLoader.LoadIcon(this, "gtk-new", Gtk.IconSize.Menu, 16);
             this.WindowPosition = ((Gtk.WindowPosition)(4));
             this.SkipPagerHint = true;
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
             // Internal child IBBoard.WarFoundry.FrmNewArmy.VBox
             Gtk.VBox w1 = this.VBox;
             w1.CanFocus = true;
             w1.Events = ((Gdk.EventMask)(256));
@@ -101,7 +101,7 @@
             // Container child table1.Gtk.Table+TableChild
             this.label1 = new Gtk.Label();
             this.label1.Name = "label1";
-            this.label1.LabelProp = Mono.Unix.Catalog.GetString("Race");
+            this.label1.LabelProp = "Race";
             this.table1.Add(this.label1);
             Gtk.Table.TableChild w6 = ((Gtk.Table.TableChild)(this.table1[this.label1]));
             w6.XOptions = ((Gtk.AttachOptions)(4));
@@ -109,7 +109,7 @@
             // Container child table1.Gtk.Table+TableChild
             this.label2 = new Gtk.Label();
             this.label2.Name = "label2";
-            this.label2.LabelProp = Mono.Unix.Catalog.GetString("Army name");
+            this.label2.LabelProp = "Army name";
             this.table1.Add(this.label2);
             Gtk.Table.TableChild w7 = ((Gtk.Table.TableChild)(this.table1[this.label2]));
             w7.TopAttach = ((uint)(1));
@@ -119,7 +119,7 @@
             // Container child table1.Gtk.Table+TableChild
             this.label3 = new Gtk.Label();
             this.label3.Name = "label3";
-            this.label3.LabelProp = Mono.Unix.Catalog.GetString("Points value");
+            this.label3.LabelProp = "Points value";
             this.table1.Add(this.label3);
             Gtk.Table.TableChild w8 = ((Gtk.Table.TableChild)(this.table1[this.label3]));
             w8.TopAttach = ((uint)(2));
@@ -145,7 +145,7 @@
             w10.Expand = false;
             w10.Fill = false;
             w10.Padding = ((uint)(6));
             // Internal child IBBoard.WarFoundry.FrmNewArmy.ActionArea
             Gtk.HButtonBox w11 = this.ActionArea;
             w11.CanFocus = true;
             w11.Events = ((Gdk.EventMask)(256));
@@ -182,7 +182,7 @@
             w14.Add(w15);
             // Container child GtkHBox1.Gtk.Container+ContainerChild
             Gtk.Label w17 = new Gtk.Label();
-            w17.LabelProp = Mono.Unix.Catalog.GetString("C_reate");
+            w17.LabelProp = "C_reate";
             w17.UseUnderline = true;
             w14.Add(w17);
             w13.Add(w14);
@@ -37,16 +37,16 @@
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
-            // Internal child IBBoard.WarFoundry.FrmNewArmy.VBox
+            // Internal child IBBoard.WarFoundry.GTK.FrmNewArmy.VBox
             Gtk.VBox w1 = this.VBox;
             w1.CanFocus = true;
@@ -145,7 +145,7 @@
             w10.Fill = false;
             w10.Padding = ((uint)(6));
-            // Internal child IBBoard.WarFoundry.FrmNewArmy.ActionArea
+            // Internal child IBBoard.WarFoundry.GTK.FrmNewArmy.ActionArea
             Gtk.HButtonBox w11 = this.ActionArea;
             w11.CanFocus = true;
--- a/gtk-gui/IBBoard.WarFoundry.GTK.FrmNewUnit.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/gtk-gui/IBBoard.WarFoundry.GTK.FrmNewUnit.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -1,14 +1,14 @@
 // ------------------------------------------------------------------------------
 //  <autogenerated>
 //      This code was generated by a tool.
-//      Mono Runtime Version: 2.0.50727.42
+//      Mono Runtime Version: 2.0.50727.1433
 // 
 //      Changes to this file may cause incorrect behavior and will be lost if 
 //      the code is regenerated.
 //  </autogenerated>
 // ------------------------------------------------------------------------------
 
-namespace IBBoard.WarFoundry {
+namespace IBBoard.WarFoundry.GTK {
     
     
     public partial class FrmNewUnit {
@@ -31,16 +31,16 @@
         
         protected virtual void Build() {
             Stetic.Gui.Initialize(this);
-            // Widget IBBoard.WarFoundry.FrmNewUnit
-            this.Name = "IBBoard.WarFoundry.FrmNewUnit";
-            this.Title = Mono.Unix.Catalog.GetString("Add new unit");
+            // Widget IBBoard.WarFoundry.GTK.FrmNewUnit
+            this.Name = "IBBoard.WarFoundry.GTK.FrmNewUnit";
+            this.Title = "Add new unit";
             this.Icon = Stetic.IconLoader.LoadIcon(this, "gtk-new", Gtk.IconSize.Menu, 16);
             this.WindowPosition = ((Gtk.WindowPosition)(4));
             this.Modal = true;
             this.SkipPagerHint = true;
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
             // Internal child IBBoard.WarFoundry.FrmNewUnit.VBox
             Gtk.VBox w1 = this.VBox;
             w1.Name = "dialog1_VBox";
             w1.BorderWidth = ((uint)(2));
@@ -55,7 +55,7 @@
             // Container child hbox1.Gtk.Box+BoxChild
             this.label1 = new Gtk.Label();
             this.label1.Name = "label1";
-            this.label1.LabelProp = Mono.Unix.Catalog.GetString("Unit Type:");
+            this.label1.LabelProp = "Unit Type:";
             this.hbox1.Add(this.label1);
             Gtk.Box.BoxChild w2 = ((Gtk.Box.BoxChild)(this.hbox1[this.label1]));
             w2.Position = 0;
@@ -95,7 +95,7 @@
             w7.Position = 0;
             w7.Expand = false;
             w7.Fill = false;
             // Internal child IBBoard.WarFoundry.FrmNewUnit.ActionArea
             Gtk.HButtonBox w8 = this.ActionArea;
             w8.Name = "dialog1_ActionArea";
             w8.Spacing = 6;
@@ -31,16 +31,16 @@
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
-            // Internal child IBBoard.WarFoundry.FrmNewUnit.VBox
+            // Internal child IBBoard.WarFoundry.GTK.FrmNewUnit.VBox
             Gtk.VBox w1 = this.VBox;
             w1.Name = "dialog1_VBox";
@@ -95,7 +95,7 @@
             w7.Expand = false;
             w7.Fill = false;
-            // Internal child IBBoard.WarFoundry.FrmNewUnit.ActionArea
+            // Internal child IBBoard.WarFoundry.GTK.FrmNewUnit.ActionArea
             Gtk.HButtonBox w8 = this.ActionArea;
             w8.Name = "dialog1_ActionArea";